@@ -1892,7 +1892,10 @@ module.exports = {
 		"18.3.6",
 		"18.3.7",
 		"18.3.8",
-		"18.3.9"
+		"18.3.9",
+		"18.3.11",
+		"18.3.12",
+		"18.3.13"
 	],
 	"102.0.4962.3": [
 		"19.0.0-alpha.1",
@@ -1975,7 +1978,10 @@ module.exports = {
 		"19.0.11",
 		"19.0.12",
 		"19.0.13",
-		"19.0.14"
+		"19.0.14",
+		"19.0.15",
+		"19.0.16",
+		"19.0.17"
 	],
 	"103.0.5044.0": [
 		"20.0.0-alpha.1",
@@ -2043,7 +2049,13 @@ module.exports = {
 		"20.0.3"
 	],
 	"104.0.5112.102": [
-		"20.1.0"
+		"20.1.0",
+		"20.1.1"
+	],
+	"104.0.5112.114": [
+		"20.1.2",
+		"20.1.3",
+		"20.1.4"
 	],
 	"105.0.5187.0": [
 		"21.0.0-alpha.1",
@@ -2069,6 +2081,27 @@ module.exports = {
 		"22.0.0-nightly.20220816",
 		"22.0.0-nightly.20220817"
 	],
+	"106.0.5216.0": [
+		"21.0.0-alpha.6",
+		"21.0.0-beta.1",
+		"21.0.0-beta.2",
+		"21.0.0-beta.3",
+		"21.0.0-beta.4",
+		"21.0.0-beta.5",
+		"22.0.0-nightly.20220822",
+		"22.0.0-nightly.20220823",
+		"22.0.0-nightly.20220824",
+		"22.0.0-nightly.20220825",
+		"22.0.0-nightly.20220829",
+		"22.0.0-nightly.20220830",
+		"22.0.0-nightly.20220831",
+		"22.0.0-nightly.20220901",
+		"22.0.0-nightly.20220902",
+		"22.0.0-nightly.20220905"
+	],
+	"106.0.5249.40": [
+		"21.0.0-beta.6"
+	],
 	"105.0.5129.0": [
 		"21.0.0-nightly.20220628",
 		"21.0.0-nightly.20220629",
@@ -2088,9 +2121,15 @@ module.exports = {
 		"21.0.0-nightly.20220718",
 		"21.0.0-nightly.20220719"
 	],
-	"106.0.5216.0": [
-		"22.0.0-nightly.20220822",
-		"22.0.0-nightly.20220823",
-		"22.0.0-nightly.20220824"
+	"107.0.5274.0": [
+		"22.0.0-nightly.20220908"
+	],
+	"107.0.5286.0": [
+		"22.0.0-nightly.20220909",
+		"22.0.0-nightly.20220912",
+		"22.0.0-nightly.20220913",
+		"22.0.0-nightly.20220914",
+		"22.0.0-nightly.20220915",
+		"22.0.0-nightly.20220916"
 	]
 };
\ No newline at end of file
